nvm.aux\_str package
====================

Submodules
----------

nvm.aux\_str.aux\_str module
----------------------------

.. automodule:: nvm.aux_str.aux_str
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nvm.aux_str
   :members:
   :undoc-members:
   :show-inheritance:
